ABIDE


Notes
-----
The Autism Brain Imaging Data Exchange (ABIDE) dataset provides previously
collected resting state functional magnetic resonance imaging datasets
from 539 individuals with ASD and 573 typical controls for the purpose
of data sharing in the broader scientific community. This grass-root
initiative involved 16 international sites, sharing 20 samples yielding
1112 datasets composed of both MRI data and an extensive array of
phenotypic information common across nearly all sites (see below).

Note that this is the preprocessed version of ABIDE provided by the
preprocess connectome projects (PCP).


Content
-------
    :'phenotypic': Behavioral information.


References
----------

For more information about this dataset's structure:
http://preprocessed-connectomes-project.github.io
http://www.childmind.org/en/healthy-brain-network/abide/

Nielsen, Jared A., et al. "Multisite functional connectivity MRI
classification of autism: ABIDE results." Frontiers in human neuroscience
7 (2013).

Licence: Consistent with the policies of the 1000 Functional Connectomes
Project, data usage is unrestricted for non-commercial research purposes.